@@ -402,25 +402,52 @@ class MCPServerBuilder:
     def create_package(self, script_path: Path, include_source: bool = False) -> bool:
         """创建分发包"""
         config = self.get_server_config(script_path)
-        
-        # 确定可执行文件路径
-        if platform.system() == "Windows":
-            exe_name = f"{config['name']}.exe"
-        else:
-            exe_name = config['name']
 
-        exe_path = self.dist_dir / exe_name
-        if not exe_path.exists():
-            print(f"❌ Executable not found: {exe_path}")
-            return False
+        # 兼容 PyInstaller 的 onefile 与 onedir 两种输出
+        base_name = config['name']
+        is_windows = platform.system() == "Windows"
+
+        # 优先检测 onefile 输出
+        if is_windows:
+            onefile_path = self.dist_dir / f"{base_name}.exe"
+            onedir_path = self.dist_dir / base_name
+            if onefile_path.exists():
+                exe_name = f"{base_name}.exe"
+                exe_path = onefile_path
+            elif onedir_path.exists() and (onedir_path / f"{base_name}.exe").exists():
+                # onedir 输出：dist/<name>/<name>.exe
+                exe_name = base_name  # 目录名作为包内名称
+                exe_path = onedir_path
+            else:
+                # 为了便于排查，输出两种候选路径
+                print(f"❌ 未找到可执行文件。已尝试：{onefile_path} 和 {(onedir_path / f'{base_name}.exe')}")
+                return False
+        else:
+            onefile_path = self.dist_dir / base_name
+            onedir_path = self.dist_dir / base_name
+            if onefile_path.exists() and onefile_path.is_file():
+                exe_name = base_name
+                exe_path = onefile_path
+            elif onedir_path.exists() and onedir_path.is_dir() and (onedir_path / base_name).exists():
+                exe_name = base_name
+                exe_path = onedir_path
+            else:
+                print(f"❌ 未找到可执行文件。已尝试：{onefile_path} 和 {(onedir_path / base_name)}")
+                return False
 
         # 创建包目录
         package_name = f"{config['name']}-{self.platform_name}-{self.timestamp}"
         package_dir = self.dist_dir / package_name
         package_dir.mkdir(exist_ok=True)
 
-        # 复制可执行文件
-        shutil.copy2(exe_path, package_dir / exe_name)
+        # 复制可执行文件或目录（支持 onedir 模式）
+        target_exec = package_dir / exe_name
+        if exe_path.is_dir():
+            # onedir：复制整个目录
+            shutil.copytree(exe_path, target_exec, dirs_exist_ok=True)
+        else:
+            # onefile：复制单个可执行文件
+            shutil.copy2(exe_path, target_exec)
 
         # 创建 requirements.txt
         self.create_complete_requirements(script_path, package_dir)
@@ -458,21 +485,26 @@ class MCPServerBuilder:
 
     def create_startup_scripts(self, package_dir: Path, exe_name: str):
         """创建启动脚本"""
+        is_onedir = (package_dir / exe_name).is_dir()
         # Windows 批处理文件
         if platform.system() == "Windows":
+            # 规范化名称，避免 onefile 模式出现 .exe.exe
+            base = exe_name[:-4] if exe_name.lower().endswith('.exe') else exe_name
+            inner = f"{exe_name}\\{base}.exe" if is_onedir else (exe_name if exe_name.lower().endswith('.exe') else f"{exe_name}.exe")
             bat_content = f"""@echo off
 echo Starting MCP Server...
-"{exe_name}" %*
+"{inner}" %*
 pause
 """
             with open(package_dir / "start.bat", "w") as f:
                 f.write(bat_content)
 
         # Unix shell 脚本
+        inner_unix = f"./{exe_name}/{exe_name}" if is_onedir else f"./{exe_name}"
         sh_content = f"""#!/bin/bash
 echo Starting MCP Server...
 cd "$(dirname "$0")"
-./{exe_name} "$@"
+{inner_unix} "$@"
 """
         sh_file = package_dir / "start.sh"
         with open(sh_file, "w") as f:
@@ -481,7 +513,15 @@ cd "$(dirname "$0")"
         # 设置执行权限
         if platform.system() != "Windows":
             os.chmod(sh_file, 0o755)
-            os.chmod(package_dir / exe_name, 0o755)
+            # 设置内部二进制可执行权限（onedir 与 onefile 区分）
+            try:
+                if is_onedir:
+                    os.chmod(package_dir / exe_name / exe_name, 0o755)
+                else:
+                    os.chmod(package_dir / exe_name, 0o755)
+            except Exception:
+                # 忽略权限设置错误以提高兼容性
+                pass
 
     def create_archive(self, package_dir: Path) -> Path:
         """创建压缩包"""
